summaryrefslogtreecommitdiff
path: root/Annex
diff options
context:
space:
mode:
authorGravatar Joey Hess <joeyh@joeyh.name>2015-08-19 12:24:55 -0400
committerGravatar Joey Hess <joeyh@joeyh.name>2015-08-19 12:24:55 -0400
commit52f4a0722c3c6f71cea0666cba3f27adc085d629 (patch)
tree3789171e5fc0628d4fcd549309333ce1cd9eb9ee /Annex
parentbbd8b63d4768c51bb804dcf03a17fdd895997ab5 (diff)
importfeed --relaxed: Avoid hitting the urls of items in the feed.
Diffstat (limited to 'Annex')
-rw-r--r--Annex/Init.hs4
1 files changed, 3 insertions, 1 deletions
diff --git a/Annex/Init.hs b/Annex/Init.hs
index fad533d13..5759adffc 100644
--- a/Annex/Init.hs
+++ b/Annex/Init.hs
@@ -138,8 +138,10 @@ probeCrippledFileSystem = do
createSymbolicLink f f2
nukeFile f2
preventWrite f
- -- Should be unable to write to the file, but some crippled
+ -- Should be unable to write to the file, unless
+ -- running as root, but some crippled
-- filesystems ignore write bit removals.
+ unlessM
not <$> catchBoolIO (writeFile f "2" >> return True)
#endif